==> risk-center-api-0.5.90-20230612.025943-8-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/PayRecognitionResultEntity.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class PayRecognitionResultEntity implements Serializable {
    private Long id;

    private Long advertId;

    private String promoteUrl;

    private String jumpUrl;

    private String audiPassAmount;

    private String patrolRecognitionAmount;

    /**
     * 落地页Id
     */
    private Long urlId;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl == null ? null : promoteUrl.trim();
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl == null ? null : jumpUrl.trim();
    }

    public String getAudiPassAmount() {
        return audiPassAmount;
    }

    public void setAudiPassAmount(String audiPassAmount) {
        this.audiPassAmount = audiPassAmount == null ? null : audiPassAmount.trim();
    }

    public String getPatrolRecognitionAmount() {
        return patrolRecognitionAmount;
    }

    public void setPatrolRecognitionAmount(String patrolRecognitionAmount) {
        this.patrolRecognitionAmount = patrolRecognitionAmount == null ? null : patrolRecognitionAmount.trim();
    }

    public Long getUrlId() {
        return urlId;
    }

    public void setUrlId(Long urlId) {
        this.urlId = urlId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> risk-center-api-0.5.91-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/PayRecognitionResultEntity.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class PayRecognitionResultEntity implements Serializable {
    private Long id;

    private Long advertId;

    private String promoteUrl;

    private String jumpUrl;

    private String audiPassAmount;

    private String audiPassScreenshot;

    /**
     * 落地页Id
     */
    private Long urlId;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl == null ? null : promoteUrl.trim();
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl == null ? null : jumpUrl.trim();
    }

    public String getAudiPassAmount() {
        return audiPassAmount;
    }

    public void setAudiPassAmount(String audiPassAmount) {
        this.audiPassAmount = audiPassAmount == null ? null : audiPassAmount.trim();
    }

    public String getAudiPassScreenshot() {
        return audiPassScreenshot;
    }

    public void setAudiPassScreenshot(String audiPassScreenshot) {
        this.audiPassScreenshot = audiPassScreenshot == null ? null : audiPassScreenshot.trim();
    }

    public Long getUrlId() {
        return urlId;
    }

    public void setUrlId(Long urlId) {
        this.urlId = urlId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
